==> org.opennms.features.topology.api-20.0.1-sources.jar: org/opennms/features/topology/api/info/item/DefaultInfoPanelItem.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.api.info.item;

import com.vaadin.ui.Component;

/**
 * Default Implementation of an {@link InfoPanelItem}.
 */
public class DefaultInfoPanelItem implements InfoPanelItem {

    private Component component;
    private String title;
    private int order;

    public DefaultInfoPanelItem withComponent(Component component) {
        this.component = component;
        return this;
    }

    public DefaultInfoPanelItem withOrder(int order) {
        this.order = order;
        return this;
    }

    public DefaultInfoPanelItem withTitle(String title) {
        this.title = title;
        return this;
    }

    @Override
    public Component getComponent() {
        return component;
    }

    @Override
    public String getTitle() {
        return title;
    }

    @Override
    public int getOrder() {
        return order;
    }
}

==> org.opennms.features.topology.api-27.0.0-20200418.081922-15-sources.jar: org/opennms/features/topology/api/info/item/DefaultInfoPanelItem.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.api.info.item;

import com.vaadin.ui.Component;

/**
 * Default Implementation of an {@link InfoPanelItem}.
 */
public class DefaultInfoPanelItem implements InfoPanelItem {

    private Component component;
    private String title;
    private int order;
    private String id;

    public DefaultInfoPanelItem withComponent(Component component) {
        this.component = component;
        return this;
    }

    public DefaultInfoPanelItem withOrder(int order) {
        this.order = order;
        return this;
    }

    public DefaultInfoPanelItem withTitle(String title) {
        this.title = title;
        return this;
    }

    public DefaultInfoPanelItem withId(String id) {
        this.id = id;
        return this;
    }

    @Override
    public Component getComponent() {
        return component;
    }

    @Override
    public String getTitle() {
        return title;
    }

    @Override
    public int getOrder() {
        return order;
    }

    @Override
    public String getId() {
        return id;
    }
}
